==> krusader_1.30.orig.tar.gz: krusader-1.30/krusader/GUI/kfnkeys.h <==
/***************************************************************************
                                kfnkeys.h
                             -------------------
    begin                : Thu May 4 2000
    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
    e-mail               : krusader@users.sourceforge.net
    web site             : http://krusader.sourceforge.net
 ---------------------------------------------------------------------------
  Description
 ***************************************************************************

  A

     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD

                                                     H e a d e r    F i l e

 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KFNKEYS_H
#define KFNKEYS_H

#include <qwidget.h>
#include <qlayout.h>
#include <qpushbutton.h>

// Function Keys widget
///////////////////////
class KFnKeys : public QWidget {
	Q_OBJECT

public:
	// constructor
  KFnKeys(QWidget *parent, char *name=0);

private:
	QPushButton *F2 ,*F3,*F4,*F5,*F6,*F7,*F8,*F9,*F10;
	QGridLayout *layout;
};

#endif

==> krusader_15.08~2015.11.01.orig.tar.gz: krusader-15.08~2015.11.01/krusader/GUI/kfnkeys.h <==
/***************************************************************************
                                kfnkeys.h
                             -------------------
    begin                : Thu May 4 2000
    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
    e-mail               : krusader@users.sourceforge.net
    web site             : http://krusader.sourceforge.net
 ---------------------------------------------------------------------------
  Description
 ***************************************************************************

  A

     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD

                                                     H e a d e r    F i l e

 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KFNKEYS_H
#define KFNKEYS_H

#include <QtWidgets/QWidget>
#include <QtWidgets/QLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QGridLayout>

class FileManagerWindow;

// Function Keys widget
///////////////////////
class KFnKeys : public QWidget
{
    Q_OBJECT

public:
    // constructor
    KFnKeys(QWidget *parent, FileManagerWindow *mainWindow);
    void updateShortcuts();

private:
    QPushButton *F2 , *F3, *F4, *F5, *F6, *F7, *F8, *F9, *F10;
    QGridLayout *layout;
    FileManagerWindow *mainWindow;
};

#endif
